#!D:\bld\gdal-split_1652397686326\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.4.3','gdal2xyz.py'
__requires__ = 'GDAL==3.4.3'
__import__('pkg_resources').run_script('GDAL==3.4.3', 'gdal2xyz.py')
